
var dvFormValidator = new Class({
	initialize: function()
	{
		// Initialize variables
		this.handlers	= Object();
		this.custom		= Object();

		// Default handlers
		this.setHandler('username',
			function (value) {
				regex=/^[a-zA-Z](([\.\-a-zA-Z0-9@])?[a-zA-Z0-9]*)*$/;
				return regex.test(value);
			}
		);

		this.setHandler('password',
			function (value) {
				regex=/^\S[\S ]{2,98}\S$/;
				return regex.test(value);
			}
		);
		
		this.setHandler('urlpath',
			function (value) {
				regex=/^(http|https):\/\/[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,5}(([0-9]{1,5})?\/.*)?$/;
				return regex.test(value);
			}
		);		

		this.setHandler('numeric',
			function (value) {
				regex=/^(\d|-)?(\d|,)*\.?\d*$/;
				return regex.test(value);
			}
		);

		this.setHandler('numeric2',
			function (value) {
				regex=/([0-9.,#&()*!@$%[_-]+)$/;
				return regex.test(value);
			}
		);
		
		this.setHandler('time',
			function (value) {
				regex=/(^[0-5][0-9]:[0-5][0-9]$)/;
				return regex.test(value);
			}
		);		

		this.setHandler('alphanumeric',
			function (value) {
				regex=/([a-zA-Z0-9.,#&()*!@$%[_-]+)$/;
				return regex.test(value);
			}
		);

		this.setHandler('email',
			function (value) {
				regex=/^[a-zA-Z0-9._-]+@([a-zA-Z0-9.-]+\.)+[a-zA-Z0-9.-]{2,4}$/;
				return regex.test(value);
			}
		);

		this.setHandler('dateformat',
			function (value) {
				regex=/(19|20)\d\d[- /.](0[1-9]|1[012])[- /.](0[1-9]|[12][0-9]|3[01])/;
				return regex.test(value);
			}
		);

		// Attach to forms with class 'form-validate'
		var forms = $$('form.form-validate');
		forms.each(function(form){ this.attachToForm(form); }, this);
	},

	setHandler: function(name, fn, en)
	{
		en = (en == '') ? true : en;
		this.handlers[name] = { enabled: en, exec: fn };
	},

	attachToForm: function(form)
	{
		// Iterate through the form object and attach the validate method to all input fields.
		$A(form.elements).each(function(el){
			el = $(el);
			if ((el.getTag() == 'input' || el.getTag() == 'button') && el.getProperty('type') == 'submit') {
				if (el.hasClass('validate')) {
					el.onclick = function(){return document.formvalidator.isValid(this.form);};
				}
			} else {
				el.addEvent('blur', function(){return document.formvalidator.validate(this);});
			}
		});
	},

	validate: function(el)
	{
		// If the field is required make sure it has a value
		if ($(el).hasClass('required')) {
			if (!($(el).getValue())) {
				this.handleResponse(false, el);
				return false;
			}
		}

		// Only validate the field if the validate class is set
		var handler = (el.className && el.className.search(/validate-([a-zA-Z0-9\_\-]+)/) != -1) ? el.className.match(/validate-([a-zA-Z0-9\_\-]+)/)[1] : "";
		if (handler == '') {
			this.handleResponse(true, el);
			return true;
		}

		// Check the additional validation types
		if ((handler) && (handler != 'none') && (this.handlers[handler]) && $(el).getValue()) {
			// Execute the validation handler and return result
			if (this.handlers[handler].exec($(el).getValue()) != true) {
				this.handleResponse(false, el);
				return false;
			}
		}

		// Return validation state
		this.handleResponse(true, el);
		return true;
	},

	isValid: function(form)
	{
		var valid = true;

		// Validate form fields
		for (var i=0;i < form.elements.length; i++) {
			if (this.validate(form.elements[i]) == false) {
				valid = false;
			}
		}

		// Run custom form validators if present
		$A(this.custom).each(function(validator){
			if (validator.exec() != true) {
				valid = false;
			}
		});

		return valid;
	},

	handleResponse: function(state, el)
	{
		// Find the label object for the given field if it exists
		if (!(el.labelref)) {
			var labels = $$('label');
			labels.each(function(label){
				if (label.getProperty('for') == el.getProperty('id')) {
					el.labelref = label;
				}
			});
		}

		// Set the element and its label (if exists) invalid state
		if (state == false) {
			if (el.getProperty('id') != 'category') {
			el.addClass('invalid'); }
			var result = '0';
			message = document.getElementById(el.getProperty('id') +'Failed');
				if (message != null) {
				message.className = (result == "0") ? "showErrorMessage" : "hideErrorMessage";
				}

			if (el.labelref) {
				$(el.labelref).addClass('invalid');
				var result = '0';
				message = document.getElementById($(el.labelref).getProperty('id') +'Failed');
					if (message != null) {
					message.className = (result == "0") ? "showErrorMessage" : "hideErrorMessage";
					}
				}


		} else {
				el.removeClass('invalid');
				var result = '1';
				message = document.getElementById(el.getProperty('id') +'Failed');
					if (message != null) {
					message.className = (result == "0") ? "showErrorMessage" : "hideErrorMessage";
					}
				

				if (el.labelref) {
					$(el.labelref).removeClass('invalid');
					var result = '1';
					message = document.getElementById($(el.labelref).getProperty('id') +'Failed');
						if (message != null) {
						message.className = (result == "0") ? "showErrorMessage" : "hideErrorMessage";
						}
				}


		}
	}
});

document.formvalidator = null;
Window.onDomReady(function(){
	document.formvalidator = new dvFormValidator();
});